pub struct AttemptDetail {
pub package: String,
pub version: String,
pub attempt: u32,
pub max_attempts: u32,
pub started_at: DateTime<Utc>,
pub ended_at: DateTime<Utc>,
pub error_class: Option<ErrorClass>,
pub next_attempt_at: Option<DateTime<Utc>>,
pub redacted_message: Option<String>,
}Expand description
Durable state record for one cargo publish attempt.
PackageProgress::attempts is the fast counter used by resume. This
detail log preserves operator-facing facts needed by status, resume
explainers, and release evidence before the final receipt exists.
Fields
package: Stringversion: Stringattempt: u32max_attempts: u32started_at: DateTime<Utc>ended_at: DateTime<Utc>error_class: Option<ErrorClass>next_attempt_at: Option<DateTime<Utc>>redacted_message: Option<String>Trait Implementations
Sourceimpl Clone for AttemptDetail
impl Clone for AttemptDetail
Sourcefn clone(&self) -> AttemptDetail
fn clone(&self) -> AttemptDetail
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AttemptDetail
impl Debug for AttemptDetail
Sourceimpl<'de> Deserialize<'de> for AttemptDetail
impl<'de> Deserialize<'de> for AttemptDetail
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for AttemptDetail
impl PartialEq for AttemptDetail
Sourcefn eq(&self, other: &AttemptDetail) -> bool
fn eq(&self, other: &AttemptDetail) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for AttemptDetail
impl Serialize for AttemptDetail
impl Eq for AttemptDetail
impl StructuralPartialEq for AttemptDetail